Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2013-07-23 Thread Tom Hacohen
Hey,

 From the setlocale man page:
If locale is NULL, the current locale is only queried, not modified.

I am only querying it there, not modifying it. It's up to the 
application to set the locale to whatever it wants, for example by 
calling setlocale with  like you've suggested.

This is *correct* don't change it. Look at ecrire for example, Ecrire 
does it right and works correctly.

--
Tom.

On 23/07/13 05:08, Daniel Juyung Seo wrote:
 Dear Tom,
 what does if the app using elm is translatable. mean?

 With setlocale LC_MESSAGES to NULL, running applications with environment
 variable with LANG doesn't translate the texts.
 const char *msg_locale = setlocale(LC_MESSAGES, NULL);

 I tried with  instead of NULL and it worked.
 const char *msg_locale = setlocale(LC_MESSAGES, ;

 Can you check this?
 Thanks.

 Daniel Juyung Seo (SeoZ)


 On Sun, Sep 18, 2011 at 4:53 PM, Enlightenment SVN 
 no-re...@enlightenment.org wrote:

 Log:
 Elm gettext: Only translate if the app using elm is translatable.

It assumes gettext is initialized before the call to elm_init.

 Author:   tasn
 Date: 2011-09-18 00:53:41 -0700 (Sun, 18 Sep 2011)
 New Revision: 63452
 Trac: http://trac.enlightenment.org/e/changeset/63452

 Modified:
trunk/elementary/src/lib/elm_config.c trunk/elementary/src/lib/elm_priv.h

 Modified: trunk/elementary/src/lib/elm_config.c
 ===
 --- trunk/elementary/src/lib/elm_config.c   2011-09-17 17:15:32 UTC
 (rev 63451)
 +++ trunk/elementary/src/lib/elm_config.c   2011-09-18 07:53:41 UTC
 (rev 63452)
 @@ -1658,12 +1658,33 @@
  _elm_rescale();
   }

 +static void
 +_translation_init()
 +{
 +#ifdef ENABLE_NLS
 +   const char *cur_dom = textdomain(NULL);
 +   const char *trans_comment = gettext();
 +   const char *msg_locale = setlocale(LC_MESSAGES, NULL);
 +
 +   /* Same concept as what glib does:
 +* We shouldn't translate if there are no translations for the
 +* application in the current locale + domain. (Unless locale is
 +* en_/C where translating only parts of the interface make some
 +* sense).
 +*/
 +   _elm_config-translate = !(strcmp (cur_dom, messages) 
 + !*trans_comment  strncmp (msg_locale, en_, 3) 
 + strcmp (msg_locale, C));
 +#endif
 +}
 +
   void
   _elm_config_init(void)
   {
  _desc_init();
  _profile_fetch_from_conf();
  _config_load();
 +   _translation_init();
  _env_get();
  _config_apply();
  _elm_config_font_overlay_apply();

 Modified: trunk/elementary/src/lib/elm_priv.h
 ===
 --- trunk/elementary/src/lib/elm_priv.h 2011-09-17 17:15:32 UTC (rev 63451)
 +++ trunk/elementary/src/lib/elm_priv.h 2011-09-18 07:53:41 UTC (rev 63452)
 @@ -28,7 +28,7 @@

   #ifdef ENABLE_NLS
   # include libintl.h
 -# define E_(string) dgettext(PACKAGE, string)
 +# define E_(string) _elm_dgettext(string)
   #else
   # define bindtextdomain(domain,dir)
   # define E_(string) (string)
 @@ -148,6 +148,7 @@

  /* Not part of the EET file */
  Eina_Bool  is_mirrored : 1;
 +   Eina_Bool  translate : 1;
   };

   struct _Elm_Module
 @@ -247,6 +248,20 @@
   extern Eina_List   *_elm_win_list;
   extern int  _elm_win_deferred_free;

 +/* Our gettext wrapper, used to disable translation of elm if the app
 + * is not translated. */
 +static inline const char *
 +_elm_dgettext(const char *string)
 +{
 +   if (EINA_UNLIKELY(_elm_config-translate == EINA_FALSE))
 + {
 +return string;
 + }
 +
 +   return dgettext(PACKAGE, string);
 +}
 +
 +
   /* Used by the paste handler */
   void _elm_entry_entry_paste(Evas_Object *obj, const char *entry);




 --
 BlackBerryreg; DevCon Americas, Oct. 18-20, San Francisco, CA
 http://p.sf.net/sfu/rim-devcon-copy2
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn

 --
 See everything from the browser to the database with AppDynamics
 Get end-to-end visibility with application monitoring from AppDynamics
 Isolate bottlenecks and diagnose root cause in seconds.
 Start your free trial of AppDynamics Pro today!
 http://pubads.g.doubleclick.net/gampad/clk?id=48808831iu=/4140/ostg.clktrk
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel



--
See everything from the browser to the database with AppDynamics
Get end-to-end visibility with application monitoring from AppDynamics
Isolate bottlenecks and diagnose root cause in 

Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2013-07-22 Thread Daniel Juyung Seo
Dear Tom,
what does if the app using elm is translatable. mean?

With setlocale LC_MESSAGES to NULL, running applications with environment
variable with LANG doesn't translate the texts.
   const char *msg_locale = setlocale(LC_MESSAGES, NULL);

I tried with  instead of NULL and it worked.
   const char *msg_locale = setlocale(LC_MESSAGES, ;

Can you check this?
Thanks.

Daniel Juyung Seo (SeoZ)


On Sun, Sep 18, 2011 at 4:53 PM, Enlightenment SVN 
no-re...@enlightenment.org wrote:

 Log:
 Elm gettext: Only translate if the app using elm is translatable.

   It assumes gettext is initialized before the call to elm_init.

 Author:   tasn
 Date: 2011-09-18 00:53:41 -0700 (Sun, 18 Sep 2011)
 New Revision: 63452
 Trac: http://trac.enlightenment.org/e/changeset/63452

 Modified:
   trunk/elementary/src/lib/elm_config.c trunk/elementary/src/lib/elm_priv.h

 Modified: trunk/elementary/src/lib/elm_config.c
 ===
 --- trunk/elementary/src/lib/elm_config.c   2011-09-17 17:15:32 UTC
 (rev 63451)
 +++ trunk/elementary/src/lib/elm_config.c   2011-09-18 07:53:41 UTC
 (rev 63452)
 @@ -1658,12 +1658,33 @@
 _elm_rescale();
  }

 +static void
 +_translation_init()
 +{
 +#ifdef ENABLE_NLS
 +   const char *cur_dom = textdomain(NULL);
 +   const char *trans_comment = gettext();
 +   const char *msg_locale = setlocale(LC_MESSAGES, NULL);
 +
 +   /* Same concept as what glib does:
 +* We shouldn't translate if there are no translations for the
 +* application in the current locale + domain. (Unless locale is
 +* en_/C where translating only parts of the interface make some
 +* sense).
 +*/
 +   _elm_config-translate = !(strcmp (cur_dom, messages) 
 + !*trans_comment  strncmp (msg_locale, en_, 3) 
 + strcmp (msg_locale, C));
 +#endif
 +}
 +
  void
  _elm_config_init(void)
  {
 _desc_init();
 _profile_fetch_from_conf();
 _config_load();
 +   _translation_init();
 _env_get();
 _config_apply();
 _elm_config_font_overlay_apply();

 Modified: trunk/elementary/src/lib/elm_priv.h
 ===
 --- trunk/elementary/src/lib/elm_priv.h 2011-09-17 17:15:32 UTC (rev 63451)
 +++ trunk/elementary/src/lib/elm_priv.h 2011-09-18 07:53:41 UTC (rev 63452)
 @@ -28,7 +28,7 @@

  #ifdef ENABLE_NLS
  # include libintl.h
 -# define E_(string) dgettext(PACKAGE, string)
 +# define E_(string) _elm_dgettext(string)
  #else
  # define bindtextdomain(domain,dir)
  # define E_(string) (string)
 @@ -148,6 +148,7 @@

 /* Not part of the EET file */
 Eina_Bool  is_mirrored : 1;
 +   Eina_Bool  translate : 1;
  };

  struct _Elm_Module
 @@ -247,6 +248,20 @@
  extern Eina_List   *_elm_win_list;
  extern int  _elm_win_deferred_free;

 +/* Our gettext wrapper, used to disable translation of elm if the app
 + * is not translated. */
 +static inline const char *
 +_elm_dgettext(const char *string)
 +{
 +   if (EINA_UNLIKELY(_elm_config-translate == EINA_FALSE))
 + {
 +return string;
 + }
 +
 +   return dgettext(PACKAGE, string);
 +}
 +
 +
  /* Used by the paste handler */
  void _elm_entry_entry_paste(Evas_Object *obj, const char *entry);




 --
 BlackBerryreg; DevCon Americas, Oct. 18-20, San Francisco, CA
 http://p.sf.net/sfu/rim-devcon-copy2
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn

--
See everything from the browser to the database with AppDynamics
Get end-to-end visibility with application monitoring from AppDynamics
Isolate bottlenecks and diagnose root cause in seconds.
Start your free trial of AppDynamics Pro today!
http://pubads.g.doubleclick.net/gampad/clk?id=48808831iu=/4140/ostg.clktrk
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-09-03 Thread Gustavo Lima Chaves
* Enlightenment SVN no-re...@enlightenment.org [2012-09-03 04:14:17 -0700]:

 Log:
 Elm layout: Fix segfault in some cases.

   Apparently this fixes stuff for Daniel Zaoui with some more complicated 
 cases.

 Author:   tasn
 Date: 2012-09-03 04:14:17 -0700 (Mon, 03 Sep 2012)
 New Revision: 76000
 Trac: http://trac.enlightenment.org/e/changeset/76000

 Modified:
   trunk/elementary/src/lib/elm_layout.c

 Modified: trunk/elementary/src/lib/elm_layout.c
 ===
 --- trunk/elementary/src/lib/elm_layout.c 2012-09-03 10:59:48 UTC (rev 
 75999)
 +++ trunk/elementary/src/lib/elm_layout.c 2012-09-03 11:14:17 UTC (rev 
 76000)
 @@ -70,7 +70,7 @@
  {
 ELM_LAYOUT_DATA_GET(obj, sd);

 -   if (sd-needs_size_calc) return;
 +   if (!sd || sd-needs_size_calc) return;
 sd-needs_size_calc = EINA_TRUE;

 evas_object_smart_changed(obj);
 @@ -83,7 +83,7 @@
  void *event_info __UNUSED__)
  {
 ELM_LAYOUT_DATA_GET(data, sd);
 -   if (ELM_WIDGET_DATA(sd)-frozen) return;
 +   if (!sd || ELM_WIDGET_DATA(sd)-frozen) return;
 ELM_LAYOUT_CLASS(ELM_WIDGET_DATA(sd)-api)-sizing_eval(data);
  }

Bad, bad. Hiding bigger bugs, for sure.




 --
 Live Security Virtual Conference
 Exclusive live event will cover all the ways today's security and
 threat landscape has changed and how IT managers can respond. Discussions
 will include endpoint security, mobile security and the latest in malware
 threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn

--
Gustavo Lima Chaves
Computer Engineer @ ProFUSION Embedded Systems

--
Live Security Virtual Conference
Exclusive live event will cover all the ways today's security and 
threat landscape has changed and how IT managers can respond. Discussions 
will include endpoint security, mobile security and the latest in malware 
threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-09-03 Thread Tom Hacohen
I completely agree. Daniel caught me in a moment of weakness and tricked 
me into committing this.

I'm reverting it now.

--
Tom.

On 03/09/12 16:48, Gustavo Lima Chaves wrote:
 * Enlightenment SVN no-re...@enlightenment.org [2012-09-03 04:14:17 -0700]:

 Log:
 Elm layout: Fix segfault in some cases.

Apparently this fixes stuff for Daniel Zaoui with some more complicated 
 cases.

 Author:   tasn
 Date: 2012-09-03 04:14:17 -0700 (Mon, 03 Sep 2012)
 New Revision: 76000
 Trac: http://trac.enlightenment.org/e/changeset/76000

 Modified:
trunk/elementary/src/lib/elm_layout.c

 Modified: trunk/elementary/src/lib/elm_layout.c
 ===
 --- trunk/elementary/src/lib/elm_layout.c2012-09-03 10:59:48 UTC (rev 
 75999)
 +++ trunk/elementary/src/lib/elm_layout.c2012-09-03 11:14:17 UTC (rev 
 76000)
 @@ -70,7 +70,7 @@
   {
  ELM_LAYOUT_DATA_GET(obj, sd);

 -   if (sd-needs_size_calc) return;
 +   if (!sd || sd-needs_size_calc) return;
  sd-needs_size_calc = EINA_TRUE;

  evas_object_smart_changed(obj);
 @@ -83,7 +83,7 @@
   void *event_info __UNUSED__)
   {
  ELM_LAYOUT_DATA_GET(data, sd);
 -   if (ELM_WIDGET_DATA(sd)-frozen) return;
 +   if (!sd || ELM_WIDGET_DATA(sd)-frozen) return;
  ELM_LAYOUT_CLASS(ELM_WIDGET_DATA(sd)-api)-sizing_eval(data);
   }

 Bad, bad. Hiding bigger bugs, for sure.




 --
 Live Security Virtual Conference
 Exclusive live event will cover all the ways today's security and
 threat landscape has changed and how IT managers can respond. Discussions
 will include endpoint security, mobile security and the latest in malware
 threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn

 --
 Gustavo Lima Chaves
 Computer Engineer @ ProFUSION Embedded Systems

 --
 Live Security Virtual Conference
 Exclusive live event will cover all the ways today's security and
 threat landscape has changed and how IT managers can respond. Discussions
 will include endpoint security, mobile security and the latest in malware
 threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel



--
Live Security Virtual Conference
Exclusive live event will cover all the ways today's security and 
threat landscape has changed and how IT managers can respond. Discussions 
will include endpoint security, mobile security and the latest in malware 
threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-09-03 Thread Daniel Juyung Seo
Good review from glima.
Thanks.

Daniel Juyung Seo (SeoZ)

On Mon, Sep 3, 2012 at 10:53 PM, Tom Hacohen tom.haco...@samsung.com wrote:
 I completely agree. Daniel caught me in a moment of weakness and tricked
 me into committing this.

 I'm reverting it now.

 --
 Tom.

 On 03/09/12 16:48, Gustavo Lima Chaves wrote:
 * Enlightenment SVN no-re...@enlightenment.org [2012-09-03 04:14:17 -0700]:

 Log:
 Elm layout: Fix segfault in some cases.

Apparently this fixes stuff for Daniel Zaoui with some more complicated 
 cases.

 Author:   tasn
 Date: 2012-09-03 04:14:17 -0700 (Mon, 03 Sep 2012)
 New Revision: 76000
 Trac: http://trac.enlightenment.org/e/changeset/76000

 Modified:
trunk/elementary/src/lib/elm_layout.c

 Modified: trunk/elementary/src/lib/elm_layout.c
 ===
 --- trunk/elementary/src/lib/elm_layout.c2012-09-03 10:59:48 UTC (rev 
 75999)
 +++ trunk/elementary/src/lib/elm_layout.c2012-09-03 11:14:17 UTC (rev 
 76000)
 @@ -70,7 +70,7 @@
   {
  ELM_LAYOUT_DATA_GET(obj, sd);

 -   if (sd-needs_size_calc) return;
 +   if (!sd || sd-needs_size_calc) return;
  sd-needs_size_calc = EINA_TRUE;

  evas_object_smart_changed(obj);
 @@ -83,7 +83,7 @@
   void *event_info __UNUSED__)
   {
  ELM_LAYOUT_DATA_GET(data, sd);
 -   if (ELM_WIDGET_DATA(sd)-frozen) return;
 +   if (!sd || ELM_WIDGET_DATA(sd)-frozen) return;
  ELM_LAYOUT_CLASS(ELM_WIDGET_DATA(sd)-api)-sizing_eval(data);
   }

 Bad, bad. Hiding bigger bugs, for sure.




 --
 Live Security Virtual Conference
 Exclusive live event will cover all the ways today's security and
 threat landscape has changed and how IT managers can respond. Discussions
 will include endpoint security, mobile security and the latest in malware
 threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn

 --
 Gustavo Lima Chaves
 Computer Engineer @ ProFUSION Embedded Systems

 --
 Live Security Virtual Conference
 Exclusive live event will cover all the ways today's security and
 threat landscape has changed and how IT managers can respond. Discussions
 will include endpoint security, mobile security and the latest in malware
 threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel



 --
 Live Security Virtual Conference
 Exclusive live event will cover all the ways today's security and
 threat landscape has changed and how IT managers can respond. Discussions
 will include endpoint security, mobile security and the latest in malware
 threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel

--
Live Security Virtual Conference
Exclusive live event will cover all the ways today's security and 
threat landscape has changed and how IT managers can respond. Discussions 
will include endpoint security, mobile security and the latest in malware 
threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-05-17 Thread Tom Hacohen
On 17/05/12 02:15, Carsten Haitzler (The Rasterman) wrote:
 the point of releases and stability is that regardless if *YOU* care, you have
 users (customers) who care and stability is about supporting them. making
 bugfix releases with no nasty surprises they can DEPEND on. if you personally
 care about the bug/widget or not is not really relevant. your USERS will care 
 -
 some of them will, AND if you care about the project at all you care about
 users and at least TRY to help them out and make them happy. there are of
 course limits and there is the other side of being unreasonable, but doing a
 backport of a fix is far from unreasonable.

It's painful and annoying. As I said, I do it. You I've done my share of 
backports in the past, it's not that I'm against them/strictly against 
them. I'm just saying it's maybe time to think about this process and 
fix it, because as I said *I* don't care (for my own sake, i.e 
scratching my own itches, like I said) about backports (and most users 
don't care much as well, but lets leave that aside) and it's a painful 
process for me to do. It just makes sense that people that care about 
the older version will maintain them. I.e just have an old version 
maintainer.

 Though seriously, changelog: no way I'm adding a changelog entry for
 that, we are really getting nuts with the changelog, we have 1
 changes like this per release which just clutters the changelog. That's

 the changelog is a small fraction of the size of the svn log. the changelog is
 for packagers and users to see what did change when they GET THE TARBALL. the
 changelog is what i use to update NEWS files at release time. scm log is
 everything. changelog is filtered down entries to the new additions, removals
 and bug fixes done - any bug fix at all that may have affected someone and
 their apps/code etc. (fixing a spelling mistakke in a comment, doc, readme 
 etc.
 isn't going to affect people normally).

I know what a changelog is for, but you have to put a line somewhere. 
I'm certain you'll agree that Fixed elm_object_text_set to work when 
inserting the text 'aouaAHA*(KAo34'. hardly deserves a changelog 
entry, as no one complained about it. I'd argue that only major bugs or 
bug that were reported deserve changelog entries, but as I said, it's 
not really defined ATM.

 what bug trackers and associating bugs with releases are for, not the
 changelog. If we plan on adding changelog entries for every small

 and then the bug tracker is cluttered with 1 changes. unlike the
 changelog you have to wait 5 seconds for each bug report page to come up, as
 opposed to a quick scan of a text file to see if your annoying bug has been
 fixed this release or not.

You can just show them all in a list and see all the titles, and it's 
grouped per release so no filtering is needed.

 change, we might as well just paste the VCS log there on release (like
 some projects do).

 no - because scm logs contain all the junk in between.

And changelog just contains a lot of other junk.

 As for the backport. It's annoying to do with svn (and our directory
 structure), very annoying, also, it's driving me nuts. Again, comparing
 to other projects: that's why there are version maintainers, just for
 backporting. When it comes to scratching my own itches: I couldn't care
 less about backports, I usually do it, but it's really just too annoying.

 just before u svn commit the change
 svn diff | (cd ~/dev/svn/e/branches/elementary-1.0; patch -p0)

 that's annoying? you could script it trivially:

 cat backport.sh
 #!/bin/sh
 svn diff | (cd ~/dev/svn/e/branches/$1; patch -p0)

 so now it's a simple:

 backport.sh elementary-1.0


1. Yes, it's terribly annoying, and you have to maintain checkouts of 
all the branches.
2. It's not as simple as you'll may have conflicts.
3. It's not as easy when you work with git-svn and have multiple commits 
in your queue (can be done, just not as trivial).

 reality is that often the changelogs (and patches) don't apply so there is a
 manual fix anyway and no scm is going to magically fix that for you. this is
 the cost of stability and doing releases. this is WHY on most large projects
 there are DEDICATED people who just do the backporting (ie maintaining) of
 stable releases. so please do this. it's the right and professional thing to
 do. our tools are just fine

That's the point of my mail! I wasn't trolling about git, we already 
said we'll move to git after e17 is out, I was just saying we need 
dedicated people to do the backporting, I'm glad we agree.

 We just need to find something to do with backporting (which will be a
 lot easier but still annoying with git) and define guidelines for when

 no easier with git. see above.

Is too, especially when you work with local commits, but also just 
because you don't need to maintain more than one checkout of the code.

 to backport (and more importantly who), and when to add changelog
 entries. It's just too crazy to go on 

Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-05-17 Thread Stefan Schmidt
Hello.

On 05/17/2012 08:05 AM, Tom Hacohen wrote:
 On 17/05/12 02:15, Carsten Haitzler (The Rasterman) wrote:

 I know what a changelog is for, but you have to put a line somewhere.
 I'm certain you'll agree that Fixed elm_object_text_set to work when
 inserting the text 'aouaAHA*(KAo34'. hardly deserves a changelog
 entry, as no one complained about it. I'd argue that only major bugs or
 bug that were reported deserve changelog entries, but as I said, it's
 not really defined ATM.

Well, if you don't have a special case for 'aouaAHA*(KAo34' this bug 
would also affect other text entries. Rare sure, but not as rare as you 
might think. Adding a changelog with the fixed _root cause_ would still 
make sense.

About the only-a-bug-when-reported I can just say this will not work. I 
agree that reported bugs have higher priority and should get an entry, 
but just because it was not reported does not mean it nobody was 
affected by it. Users are as lazy as developers in this regard. :)

 As for the backport. It's annoying to do with svn (and our directory
 structure), very annoying, also, it's driving me nuts. Again, comparing
 to other projects: that's why there are version maintainers, just for
 backporting. When it comes to scratching my own itches: I couldn't care
 less about backports, I usually do it, but it's really just too annoying.

 just before u svn commit the change
 svn diff | (cd ~/dev/svn/e/branches/elementary-1.0; patch -p0)

 that's annoying? you could script it trivially:

 cat backport.sh
 #!/bin/sh
 svn diff | (cd ~/dev/svn/e/branches/$1; patch -p0)

 so now it's a simple:

 backport.sh elementary-1.0


 1. Yes, it's terribly annoying, and you have to maintain checkouts of
 all the branches.

I actually would expect this from developers.

 2. It's not as simple as you'll may have conflicts.

Sure. And form time to time its even not sensible to do so because too 
much internals changed. Naturally backports will slow down to the most 
important ones while code in the dev branch moves on. More likely to 
happen with elementary right now then say for embryo.

 3. It's not as easy when you work with git-svn and have multiple commits
 in your queue (can be done, just not as trivial).

I'm sorry, but that really reads like an excuse because do don't want to 
use your tools in a better way. Making a new branch and bringing over 
the commits you want to commit and then backport is not that hard with 
git. You can then rebase, or merge. Local changes come with a cost.

 As I said, I know it's important, I'm just saying my direct motivation
 is to improve the EFL and not to support users. I do support users, I
 help on the ML/IRC and generally available. I care about EFL flourishing
 and that's why I even bother about arguing. I'm just saying it's getting
 a bit annoying.
 Heck, I've been bugging everyone for years to write proper commit logs,
 doc the code and write unit tests, which achieves stability and more.

We all pester for efl and e17 releases for years and now that we have 
some we need to take care about doing some maintenance as well. Price to 
pay.

 We need to optimise the way we work, not only the code we write, and
 at the moment, we are very far from ideal in that field.

I heartfully agree with you on this. Still just ripping out parts of the 
workflow that are useful for others is no optimisation but a simple 
feature removal to save time. :)

 Just think about the time wasted, people annoyed by it (me for one) and
 compare it to the outcome and the benefits we get from it and let us
 know if you still think we should go on the way we do.

Interestingly it seems to be easy enough to do backports for raster and 
cedric. For me it looks like your own setup makes it harder then needed. 
(No complete checkout, local commits). There is nothing in git and 
git-svn that would block you from having a good setup for this.

regards
Stefan Schmidt

--
Live Security Virtual Conference
Exclusive live event will cover all the ways today's security and 
threat landscape has changed and how IT managers can respond. Discussions 
will include endpoint security, mobile security and the latest in malware 
threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-05-16 Thread Davide Andreoli
2012/5/16 Enlightenment SVN no-re...@enlightenment.org

 Log:
 Elm fileselector_button: Fixed a bug when choosing a file.

 Author:   tasn
 Date: 2012-05-16 05:12:34 -0700 (Wed, 16 May 2012)
 New Revision: 71165
 Trac: http://trac.enlightenment.org/e/changeset/71165


Changelog? Backport?  no?
davemds



 Modified:
  trunk/elementary/src/lib/elc_fileselector_button.c

 Modified: trunk/elementary/src/lib/elc_fileselector_button.c
 ===
 --- trunk/elementary/src/lib/elc_fileselector_button.c  2012-05-16
 11:57:46 UTC (rev 71164)
 +++ trunk/elementary/src/lib/elc_fileselector_button.c  2012-05-16
 12:12:34 UTC (rev 71165)
 @@ -107,7 +107,7 @@
evas_object_del(del);

evas_object_smart_callback_call
 - (ELM_WIDGET_DATA(sd)-obj, SIG_FILE_CHOSEN, (void *)sd-fsd.path);
 + (ELM_WIDGET_DATA(sd)-obj, SIG_FILE_CHOSEN, file);
  }

  static Evas_Object *



 --
 Live Security Virtual Conference
 Exclusive live event will cover all the ways today's security and
 threat landscape has changed and how IT managers can respond. Discussions
 will include endpoint security, mobile security and the latest in malware
 threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn

--
Live Security Virtual Conference
Exclusive live event will cover all the ways today's security and 
threat landscape has changed and how IT managers can respond. Discussions 
will include endpoint security, mobile security and the latest in malware 
threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-05-16 Thread Tom Hacohen
On 16/05/12 22:02, Davide Andreoli wrote:
 Changelog? Backport?  no?

Changelog: fix a stupid bug in a widget no one uses (but my colleague it
seems).

Though seriously, changelog: no way I'm adding a changelog entry for
that, we are really getting nuts with the changelog, we have 1
changes like this per release which just clutters the changelog. That's
what bug trackers and associating bugs with releases are for, not the
changelog. If we plan on adding changelog entries for every small
change, we might as well just paste the VCS log there on release (like
some projects do).

As for the backport. It's annoying to do with svn (and our directory
structure), very annoying, also, it's driving me nuts. Again, comparing
to other projects: that's why there are version maintainers, just for
backporting. When it comes to scratching my own itches: I couldn't care
less about backports, I usually do it, but it's really just too annoying.

We just need to find something to do with backporting (which will be a
lot easier but still annoying with git) and define guidelines for when
to backport (and more importantly who), and when to add changelog
entries. It's just too crazy to go on like that. People are motivated
about improving EFL, not supporting the debian-afraid-of-updates gang.

Just my thoughts. :)

--
Tom.

--
Live Security Virtual Conference
Exclusive live event will cover all the ways today's security and 
threat landscape has changed and how IT managers can respond. Discussions 
will include endpoint security, mobile security and the latest in malware 
threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-05-16 Thread The Rasterman
On Wed, 16 May 2012 23:59:38 +0300 Tom Hacohen t...@stosb.com said:

 On 16/05/12 22:02, Davide Andreoli wrote:
  Changelog? Backport?  no?
 
 Changelog: fix a stupid bug in a widget no one uses (but my colleague it
 seems).

the point of releases and stability is that regardless if *YOU* care, you have
users (customers) who care and stability is about supporting them. making
bugfix releases with no nasty surprises they can DEPEND on. if you personally
care about the bug/widget or not is not really relevant. your USERS will care -
some of them will, AND if you care about the project at all you care about
users and at least TRY to help them out and make them happy. there are of
course limits and there is the other side of being unreasonable, but doing a
backport of a fix is far from unreasonable.

 Though seriously, changelog: no way I'm adding a changelog entry for
 that, we are really getting nuts with the changelog, we have 1
 changes like this per release which just clutters the changelog. That's

the changelog is a small fraction of the size of the svn log. the changelog is
for packagers and users to see what did change when they GET THE TARBALL. the
changelog is what i use to update NEWS files at release time. scm log is
everything. changelog is filtered down entries to the new additions, removals
and bug fixes done - any bug fix at all that may have affected someone and
their apps/code etc. (fixing a spelling mistakke in a comment, doc, readme etc.
isn't going to affect people normally).

 what bug trackers and associating bugs with releases are for, not the
 changelog. If we plan on adding changelog entries for every small

and then the bug tracker is cluttered with 1 changes. unlike the
changelog you have to wait 5 seconds for each bug report page to come up, as
opposed to a quick scan of a text file to see if your annoying bug has been
fixed this release or not.

 change, we might as well just paste the VCS log there on release (like
 some projects do).

no - because scm logs contain all the junk in between.

 As for the backport. It's annoying to do with svn (and our directory
 structure), very annoying, also, it's driving me nuts. Again, comparing
 to other projects: that's why there are version maintainers, just for
 backporting. When it comes to scratching my own itches: I couldn't care
 less about backports, I usually do it, but it's really just too annoying.

just before u svn commit the change
svn diff | (cd ~/dev/svn/e/branches/elementary-1.0; patch -p0)

that's annoying? you could script it trivially:

cat backport.sh
#!/bin/sh
svn diff | (cd ~/dev/svn/e/branches/$1; patch -p0)

so now it's a simple:

backport.sh elementary-1.0

reality is that often the changelogs (and patches) don't apply so there is a
manual fix anyway and no scm is going to magically fix that for you. this is
the cost of stability and doing releases. this is WHY on most large projects
there are DEDICATED people who just do the backporting (ie maintaining) of
stable releases. so please do this. it's the right and professional thing to
do. our tools are just fine

 We just need to find something to do with backporting (which will be a
 lot easier but still annoying with git) and define guidelines for when

no easier with git. see above.

 to backport (and more importantly who), and when to add changelog
 entries. It's just too crazy to go on like that. People are motivated
 about improving EFL, not supporting the debian-afraid-of-updates gang.

and then all your serious users run away because you can't be bothered
maintaining any stability that they RELY on in their
servers/products/devices/apps and they go and find somone else who bothers. if
you just want to hack in a bubble then fine, but we are now in a position of
needing to maintain stability. if you are uninterested in helping out and
instead now making others do your backport for you when it's easier to do
yourself at the time (much easier - see above), then perhaps this isn't the
project for you?

 Just my thoughts. :)
 
 --
 Tom.
 
 --
 Live Security Virtual Conference
 Exclusive live event will cover all the ways today's security and 
 threat landscape has changed and how IT managers can respond. Discussions 
 will include endpoint security, mobile security and the latest in malware 
 threats. http://www.accelacomm.com/jaw/sfrnl04242012/114/50122263/
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel
 


-- 
- Codito, ergo sum - I code, therefore I am --
The Rasterman (Carsten Haitzler)ras...@rasterman.com


--
Live Security Virtual Conference
Exclusive live event will cover all the ways today's security and 
threat landscape has 

Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-02-20 Thread Daniel Juyung Seo
This introduces following warnings.

elm_gesture_layer.c: In function '_add_device_pending':
elm_gesture_layer.c:859:13: warning: passing argument 3 of
'eina_list_search_unsorted_list' makes pointer from integer without a cast
/usr/local/include/eina-1/eina/eina_list.h:1163:28: note: expected 'const
void *' but argument is of type 'int'
elm_gesture_layer.c:861:9: warning: passing argument 2 of
'eina_list_append' makes pointer from integer without a cast
/usr/local/include/eina-1/eina/eina_list.h:373:28: note: expected 'const
void *' but argument is of type 'int'
elm_gesture_layer.c: In function '_device_is_pending':
elm_gesture_layer.c:889:10: warning: passing argument 3 of
'eina_list_search_unsorted_list' makes pointer from integer without a cast
/usr/local/include/eina-1/eina/eina_list.h:1163:28: note: expected 'const
void *' but argument is of type 'int'


Daniel Juyung Seo (SeoZ)

On Mon, Feb 20, 2012 at 6:23 PM, Enlightenment SVN 
no-re...@enlightenment.org wrote:

 Log:
 Elm glayer: Fixed wrong usage of intptr_t.

  Spank Spank.

 Author:   tasn
 Date: 2012-02-20 01:23:19 -0800 (Mon, 20 Feb 2012)
 New Revision: 68150
 Trac: http://trac.enlightenment.org/e/changeset/68150

 Modified:
  trunk/elementary/src/lib/elm_gesture_layer.c

 Modified: trunk/elementary/src/lib/elm_gesture_layer.c
 ===
 --- trunk/elementary/src/lib/elm_gesture_layer.c2012-02-20
 09:22:23 UTC (rev 68149)
 +++ trunk/elementary/src/lib/elm_gesture_layer.c2012-02-20
 09:23:19 UTC (rev 68150)
 @@ -856,9 +856,9 @@
  }

if (!eina_list_search_unsorted_list(list, device_in_pending_list,
 -(intptr_t*) device))
 +(intptr_t) device))
  {
 -return eina_list_append(list, (intptr_t*) device);
 +return eina_list_append(list, (intptr_t) device);
  }

return list;
 @@ -886,7 +886,7 @@
  }

return eina_list_search_unsorted_list(list, device_in_pending_list,
 - (intptr_t *) device);
 + (intptr_t) device);
  }

  /**



 --
 Try before you buy = See our experts in action!
 The most comprehensive online learning library for Microsoft developers
 is just $99.99! Visual Studio, SharePoint, SQL - plus HTML5, CSS3, MVC3,
 Metro Style Apps, more. Free future releases when you subscribe now!
 http://p.sf.net/sfu/learndevnow-dev2
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn

--
Keep Your Developer Skills Current with LearnDevNow!
The most comprehensive online learning library for Microsoft developers
is just $99.99! Visual Studio, SharePoint, SQL - plus HTML5, CSS3, MVC3,
Metro Style Apps, more. Free future releases when you subscribe now!
http://p.sf.net/sfu/learndevnow-d2d
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-02-20 Thread ChunEon Park
We may need to use (size_t) data types.
If there are no definitions of the above things, then our configuration can 
define them based on the CPU architecture.

-Regards, Hermet-
 
-Original Message-
From: Daniel Juyung Seolt;seojuyu...@gmail.comgt; 
To: enlightenment-devel@lists.sourceforge.net
Cc: enlightenment-...@lists.sourceforge.net
Sent: 12-02-21(화) 10:56:54
Subject: Re: [E-devel] E SVN: tasn trunk/elementary/src/lib
This introduces following warnings.
elm_gesture_layer.c: In function '_add_device_pending':
elm_gesture_layer.c:859:13: warning: passing argument 3 of
'eina_list_search_unsorted_list' makes pointer from integer without a cast
/usr/local/include/eina-1/eina/eina_list.h:1163:28: note: expected 'const
void *' but argument is of type 'int'
elm_gesture_layer.c:861:9: warning: passing argument 2 of
'eina_list_append' makes pointer from integer without a cast
/usr/local/include/eina-1/eina/eina_list.h:373:28: note: expected 'const
void *' but argument is of type 'int'
elm_gesture_layer.c: In function '_device_is_pending':
elm_gesture_layer.c:889:10: warning: passing argument 3 of
'eina_list_search_unsorted_list' makes pointer from integer without a cast
/usr/local/include/eina-1/eina/eina_list.h:1163:28: note: expected 'const
void *' but argument is of type 'int'
Daniel Juyung Seo (SeoZ)
On Mon, Feb 20, 2012 at 6:23 PM, Enlightenment SVN lt;
no-re...@enlightenment.org wrote:
 Log:
 Elm glayer: Fixed wrong usage of intptr_t.

 Spank Spank.

 Author: tasn
 Date: 2012-02-20 01:23:19 -0800 (Mon, 20 Feb 2012)
 New Revision: 68150
 Trac: http://trac.enlightenment.org/e/changeset/68150

 Modified:
 trunk/elementary/src/lib/elm_gesture_layer.c

 Modified: trunk/elementary/src/lib/elm_gesture_layer.c
 ===
 --- trunk/elementary/src/lib/elm_gesture_layer.c 2012-02-20
 09:22:23 UTC (rev 68149)
 +++ trunk/elementary/src/lib/elm_gesture_layer.c 2012-02-20
 09:23:19 UTC (rev 68150)
 @@ -856,9 +856,9 @@
 }

 if (!eina_list_search_unsorted_list(list, device_in_pending_list,
 - (intptr_t*) device))
 + (intptr_t) device))
 {
 - return eina_list_append(list, (intptr_t*) device);
 + return eina_list_append(list, (intptr_t) device);
 }

 return list;
 @@ -886,7 +886,7 @@
 }

 return eina_list_search_unsorted_list(list, device_in_pending_list,
 - (intptr_t *) device);
 + (intptr_t) device);
 }

 /**



 --
 Try before you buy = See our experts in action!
 The most comprehensive online learning library for Microsoft developers
 is just $99.99! Visual Studio, SharePoint, SQL - plus HTML5, CSS3, MVC3,
 Metro Style Apps, more. Free future releases when you subscribe now!
 http://p.sf.net/sfu/learndevnow-dev2
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn

--
Keep Your Developer Skills Current with LearnDevNow!
The most comprehensive online learning library for Microsoft developers
is just $99.99! Visual Studio, SharePoint, SQL - plus HTML5, CSS3, MVC3,
Metro Style Apps, more. Free future releases when you subscribe now!
http://p.sf.net/sfu/learndevnow-d2d
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel
--
Keep Your Developer Skills Current with LearnDevNow!
The most comprehensive online learning library for Microsoft developers
is just $99.99! Visual Studio, SharePoint, SQL - plus HTML5, CSS3, MVC3,
Metro Style Apps, more. Free future releases when you subscribe now!
http://p.sf.net/sfu/learndevnow-d2d
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-02-17 Thread Tom Hacohen
Just to conform with pager... look at the bottom of the .h file, you
have the item style default set function...

--
Tom.

On 17/02/12 04:56, ChunEon Park wrote:
 Why does elm_naviframe_item_style_default_set API required?
 This API says that elm_object_style_default_set is also needed.
 
 -Regards, Hermet-
  
 -Original Message-
 From: Enlightenment SVNlt;no-re...@enlightenment.orggt; 
 To: enlightenment-...@lists.sourceforge.net
 Cc: 
 Sent: 12-02-16(목) 01:27:34
 Subject: E SVN: tasn trunk/elementary/src/lib
 Log:
 Elm naviframe: Fix naviframe a little and add item default style set/get
  
  1. items_get is no longer completely broken
  2. default style set/get is used as a replacement for the style NULL
 Author: tasn
 Date: 2012-02-15 08:27:34 -0800 (Wed, 15 Feb 2012)
 New Revision: 67989
 Trac: http://trac.enlightenment.org/e/changeset/67989
 Modified:
  trunk/elementary/src/lib/elc_naviframe.c 
 trunk/elementary/src/lib/elc_naviframe.h 
 Modified: trunk/elementary/src/lib/elc_naviframe.c
 ===
 --- trunk/elementary/src/lib/elc_naviframe.c 2012-02-15 15:33:54 UTC (rev 
 67988)
 +++ trunk/elementary/src/lib/elc_naviframe.c 2012-02-15 16:27:34 UTC (rev 
 67989)
 @@ -13,6 +13,7 @@
  Eina_Bool preserve: 1;
  Eina_Bool auto_pushed: 1;
  Eina_Bool freeze_events: 1;
 + Eina_Stringshare *item_style;
  };
  
  struct _Elm_Naviframe_Content_Item_Pair
 @@ -180,6 +181,7 @@
  if (!wd-stack) break;
  }
  }
 + eina_stringshare_del(wd-item_style);
  free(wd);
  }
  
 @@ -906,13 +908,14 @@
  Elm_Naviframe_Content_Item_Pair *content_pair;
  Elm_Naviframe_Text_Item_Pair *text_pair;
  Widget_Data *wd;
 + wd = elm_widget_data_get(WIDGET(navi_it));
 + if (!wd) return;
  
  char buf[256];
  
  if (!item_style)
  {
 - strcpy(buf, item/basic);
 - eina_stringshare_replace(navi_it-style, basic);
 + snprintf(buf, sizeof(buf), item/%s, wd-item_style);
  }
  else
  {
 @@ -950,9 +953,6 @@
  navi_it-title_visible = EINA_TRUE;
  _sizing_eval(WIDGET(navi_it));
  
 - wd = elm_widget_data_get(WIDGET(navi_it));
 - if (!wd) return;
 -
  if (wd-freeze_events)
  evas_object_freeze_events_set(VIEW(navi_it), EINA_FALSE);
  }
 @@ -1070,6 +1070,7 @@
  
  wd-auto_pushed = EINA_TRUE;
  wd-freeze_events = EINA_TRUE;
 + wd-item_style = eina_stringshare_add(basic);
  
  return obj;
  }
 @@ -1329,11 +1330,11 @@
  Elm_Naviframe_Item *navi_it = (Elm_Naviframe_Item *) it;
  
  //Return if new style is exsiting one.
 - if (item_style)
 - if (!strcmp(item_style, navi_it-style)) return;
 + if ((item_style  navi_it-style)  (!strcmp(item_style, navi_it-style)))
 + return;
  
 - if (!item_style)
 - if (!strcmp(basic, navi_it-style)) return;
 + if ((!item_style)  (!navi_it-style))
 + return;
  
  _item_style_set(navi_it, item_style);
  }
 @@ -1385,13 +1386,19 @@
  return wd-auto_pushed;
  }
  
 -EAPI Eina_Inlist *
 +EAPI Eina_List *
  elm_naviframe_items_get(const Evas_Object *obj)
  {
  ELM_CHECK_WIDTYPE(obj, widtype) NULL;
  Widget_Data *wd = elm_widget_data_get(obj);
  if (!wd) return NULL;
 - return wd-stack;
 + Eina_List *ret = NULL;
 + Elm_Naviframe_Item *itr;
 + EINA_INLIST_FOREACH(wd-stack, itr)
 + {
 + ret = eina_list_append(ret, itr);
 + }
 + return ret;
  }
  
  EAPI void
 @@ -1413,3 +1420,22 @@
  if (!wd) return EINA_FALSE;
  return !wd-freeze_events;
  }
 +
 +EAPI void
 +elm_naviframe_item_style_default_set(Evas_Object *obj, const char *style)
 +{
 + ELM_CHECK_WIDTYPE(obj, widtype);
 + Widget_Data *wd = elm_widget_data_get(obj);
 + if (!wd) return;
 + eina_stringshare_replace(wd-item_style, style);
 + _theme_hook(obj);
 +}
 +
 +EAPI const char *
 +elm_naviframe_item_style_default_get(const Evas_Object *obj)
 +{
 + ELM_CHECK_WIDTYPE(obj, widtype) NULL;
 + Widget_Data *wd = elm_widget_data_get(obj);
 + if (!wd) return NULL;
 + return wd-item_style;
 +}
 Modified: trunk/elementary/src/lib/elc_naviframe.h
 ===
 --- trunk/elementary/src/lib/elc_naviframe.h 2012-02-15 15:33:54 UTC (rev 
 67988)
 +++ trunk/elementary/src/lib/elc_naviframe.h 2012-02-15 16:27:34 UTC (rev 
 67989)
 @@ -320,12 +320,12 @@
  * @brief Get a list of all the naviframe items.
  *
  * @param obj The naviframe object
 - * @return An Eina_Inlist* of naviframe items, #Elm_Object_Item,
 + * @return An Eina_List of naviframe items, #Elm_Object_Item,
  * or @c NULL on failure.
  *
  * @ingroup Naviframe
  */
 -EAPI Eina_Inlist *elm_naviframe_items_get(const Evas_Object *obj);
 +EAPI Eina_List *elm_naviframe_items_get(const Evas_Object *obj) EINA_MALLOC 
 EINA_WARN_UNUSED_RESULT;
  
  /**
  * @brief Set the event enabled when pushing/popping items
 @@ -361,5 +361,29 @@
  EAPI Eina_Bool elm_naviframe_event_enabled_get(const Evas_Object *obj);
  
  /**
 + * @brief Set the default item style.
 + *
 + * Default item style will be used with items who's style is NULL
 + *
 + * @param obj The naviframe object
 + * @param style 

Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2012-02-16 Thread ChunEon Park
Why does elm_naviframe_item_style_default_set API required?
This API says that elm_object_style_default_set is also needed.

-Regards, Hermet-
 
-Original Message-
From: Enlightenment SVNlt;no-re...@enlightenment.orggt; 
To: enlightenment-...@lists.sourceforge.net
Cc: 
Sent: 12-02-16(목) 01:27:34
Subject: E SVN: tasn trunk/elementary/src/lib
Log:
Elm naviframe: Fix naviframe a little and add item default style set/get
 
 1. items_get is no longer completely broken
 2. default style set/get is used as a replacement for the style NULL
Author: tasn
Date: 2012-02-15 08:27:34 -0800 (Wed, 15 Feb 2012)
New Revision: 67989
Trac: http://trac.enlightenment.org/e/changeset/67989
Modified:
 trunk/elementary/src/lib/elc_naviframe.c 
trunk/elementary/src/lib/elc_naviframe.h 
Modified: trunk/elementary/src/lib/elc_naviframe.c
===
--- trunk/elementary/src/lib/elc_naviframe.c 2012-02-15 15:33:54 UTC (rev 67988)
+++ trunk/elementary/src/lib/elc_naviframe.c 2012-02-15 16:27:34 UTC (rev 67989)
@@ -13,6 +13,7 @@
 Eina_Bool preserve: 1;
 Eina_Bool auto_pushed: 1;
 Eina_Bool freeze_events: 1;
+ Eina_Stringshare *item_style;
 };
 
 struct _Elm_Naviframe_Content_Item_Pair
@@ -180,6 +181,7 @@
 if (!wd-stack) break;
 }
 }
+ eina_stringshare_del(wd-item_style);
 free(wd);
 }
 
@@ -906,13 +908,14 @@
 Elm_Naviframe_Content_Item_Pair *content_pair;
 Elm_Naviframe_Text_Item_Pair *text_pair;
 Widget_Data *wd;
+ wd = elm_widget_data_get(WIDGET(navi_it));
+ if (!wd) return;
 
 char buf[256];
 
 if (!item_style)
 {
- strcpy(buf, item/basic);
- eina_stringshare_replace(navi_it-style, basic);
+ snprintf(buf, sizeof(buf), item/%s, wd-item_style);
 }
 else
 {
@@ -950,9 +953,6 @@
 navi_it-title_visible = EINA_TRUE;
 _sizing_eval(WIDGET(navi_it));
 
- wd = elm_widget_data_get(WIDGET(navi_it));
- if (!wd) return;
-
 if (wd-freeze_events)
 evas_object_freeze_events_set(VIEW(navi_it), EINA_FALSE);
 }
@@ -1070,6 +1070,7 @@
 
 wd-auto_pushed = EINA_TRUE;
 wd-freeze_events = EINA_TRUE;
+ wd-item_style = eina_stringshare_add(basic);
 
 return obj;
 }
@@ -1329,11 +1330,11 @@
 Elm_Naviframe_Item *navi_it = (Elm_Naviframe_Item *) it;
 
 //Return if new style is exsiting one.
- if (item_style)
- if (!strcmp(item_style, navi_it-style)) return;
+ if ((item_style  navi_it-style)  (!strcmp(item_style, navi_it-style)))
+ return;
 
- if (!item_style)
- if (!strcmp(basic, navi_it-style)) return;
+ if ((!item_style)  (!navi_it-style))
+ return;
 
 _item_style_set(navi_it, item_style);
 }
@@ -1385,13 +1386,19 @@
 return wd-auto_pushed;
 }
 
-EAPI Eina_Inlist *
+EAPI Eina_List *
 elm_naviframe_items_get(const Evas_Object *obj)
 {
 ELM_CHECK_WIDTYPE(obj, widtype) NULL;
 Widget_Data *wd = elm_widget_data_get(obj);
 if (!wd) return NULL;
- return wd-stack;
+ Eina_List *ret = NULL;
+ Elm_Naviframe_Item *itr;
+ EINA_INLIST_FOREACH(wd-stack, itr)
+ {
+ ret = eina_list_append(ret, itr);
+ }
+ return ret;
 }
 
 EAPI void
@@ -1413,3 +1420,22 @@
 if (!wd) return EINA_FALSE;
 return !wd-freeze_events;
 }
+
+EAPI void
+elm_naviframe_item_style_default_set(Evas_Object *obj, const char *style)
+{
+ ELM_CHECK_WIDTYPE(obj, widtype);
+ Widget_Data *wd = elm_widget_data_get(obj);
+ if (!wd) return;
+ eina_stringshare_replace(wd-item_style, style);
+ _theme_hook(obj);
+}
+
+EAPI const char *
+elm_naviframe_item_style_default_get(const Evas_Object *obj)
+{
+ ELM_CHECK_WIDTYPE(obj, widtype) NULL;
+ Widget_Data *wd = elm_widget_data_get(obj);
+ if (!wd) return NULL;
+ return wd-item_style;
+}
Modified: trunk/elementary/src/lib/elc_naviframe.h
===
--- trunk/elementary/src/lib/elc_naviframe.h 2012-02-15 15:33:54 UTC (rev 67988)
+++ trunk/elementary/src/lib/elc_naviframe.h 2012-02-15 16:27:34 UTC (rev 67989)
@@ -320,12 +320,12 @@
 * @brief Get a list of all the naviframe items.
 *
 * @param obj The naviframe object
  * @return An Eina_Inlist* of naviframe items, #Elm_Object_Item,
 * or @c NULL on failure.
 *
 * @ingroup Naviframe
 */
-EAPI Eina_Inlist *elm_naviframe_items_get(const Evas_Object *obj);
+EAPI Eina_List *elm_naviframe_items_get(const Evas_Object *obj) EINA_MALLOC 
EINA_WARN_UNUSED_RESULT;
 
 /**
 * @brief Set the event enabled when pushing/popping items
@@ -361,5 +361,29 @@
 EAPI Eina_Bool elm_naviframe_event_enabled_get(const Evas_Object *obj);
 
 /**
+ * @brief Set the default item style.
+ *
+ * Default item style will be used with items who's style is NULL
+ *
+ * @param obj The naviframe object
+ * @param style The style
+ *
+ * @ingroup Naviframe
+ */
+EAPI void elm_naviframe_item_style_default_set(Evas_Object *obj, const char 
*style);
+
+/**
+ * @brief Get the default item style
+ *
+ * @param obj The naviframe object
+ * @return the default item style
+ *
+ * @see elm_naviframe_item_style_default_set()
+ *
+ * @ingroup Naviframe
+ */
+EAPI 
@@ -320,12 +320,12 @@
 *
 * @param obj The naviframe object
- * @return An Eina_Inlist* of naviframe items, #Elm_Object_Item,
+ * @return An Eina_List of naviframe items, #Elm_Object_Item,
 * or @c NULL on failure.
 *

Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-12-08 Thread Tom Hacohen
On 08/12/11 04:43, Daniel Juyung Seo wrote:
 Hello Tom,
 Thanks for you fix.

 I have one question here.
 I think this macro has no big benefit.

 +#define BASE(it) ((it)-base)

 There is no much difference between BASE(it) and it-base.
 But there are two macros for base.view and base.widget in elm_widget.h

 #define VIEW(X) X-base.view
 #define WIDGET(X) X-base.widget

 If BASE macro is necessary, the best place is elm_widget.h.
 Thank you.

Dear Daniel,

The reason I used BASE was because I didn't/couldn't assume the name of 
that structure field. doing it-base is bad, because base is never 
clearly stated anywhere there. Doing it in a macro/casting would have 
been more appropriate, that's why I chose the one option that can easily 
be turned to both.

I didn't do anything drastic, because I don't know those changes well 
enough. I'd expect to have a function/macro to retrieve the disabled 
status from an Elm_Object_Item.

Please think about it and decide what you think is needed to be done.

--
Tom.

--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and packaging model 
of a cloud services business. Read Now!
http://www.accelacomm.com/jaw/sfnl/114/51491232/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-12-08 Thread ChunEon Park
Simply, we can call
 
elm_widget_item_disabled_get(item);
it's more clear.

-Regards, Hermet-
 
-Original Message-
From: Tom Hacohenlt;tom.haco...@partner.samsung.comgt; 
To: Enlightenment developer 
listlt;enlightenment-devel@lists.sourceforge.netgt;
Cc: enlightenment-...@lists.sourceforge.net
Sent: 11-12-08(목) 17:05:56
Subject: Re: [E-devel] E SVN: tasn trunk/elementary/src/lib
On 08/12/11 04:43, Daniel Juyung Seo wrote:
 Hello Tom,
 Thanks for you fix.

 I have one question here.
 I think this macro has no big benefit.

 +#define BASE(it) ((it)-base)

 There is no much difference between BASE(it) and it-base.
 But there are two macros for base.view and base.widget in elm_widget.h

 #define VIEW(X) X-base.view
 #define WIDGET(X) X-base.widget

 If BASE macro is necessary, the best place is elm_widget.h.
 Thank you.
Dear Daniel,
The reason I used BASE was because I didn't/couldn't assume the name of 
that structure field. doing it-base is bad, because base is never 
clearly stated anywhere there. Doing it in a macro/casting would have 
been more appropriate, that's why I chose the one option that can easily 
be turned to both.
I didn't do anything drastic, because I don't know those changes well 
enough. I'd expect to have a function/macro to retrieve the disabled 
status from an Elm_Object_Item.
Please think about it and decide what you think is needed to be done.
--
Tom.
--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and packaging model 
of a cloud services business. Read Now!
http://www.accelacomm.com/jaw/sfnl/114/51491232/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel
--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and packaging model 
of a cloud services business. Read Now!
http://www.accelacomm.com/jaw/sfnl/114/51491232/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-12-08 Thread ChunEon Park
simply, we can call elm_widget_item_disabled_get API
it's more clear.

-Regards, Hermet-
 
-Original Message-
From: Tom Hacohenlt;tom.haco...@partner.samsung.comgt; 
To: Enlightenment developer 
listlt;enlightenment-devel@lists.sourceforge.netgt;
Cc: enlightenment-...@lists.sourceforge.net
Sent: 11-12-08(목) 17:05:56
Subject: Re: [E-devel] E SVN: tasn trunk/elementary/src/lib
On 08/12/11 04:43, Daniel Juyung Seo wrote:
 Hello Tom,
 Thanks for you fix.

 I have one question here.
 I think this macro has no big benefit.

 +#define BASE(it) ((it)-base)

 There is no much difference between BASE(it) and it-base.
 But there are two macros for base.view and base.widget in elm_widget.h

 #define VIEW(X) X-base.view
 #define WIDGET(X) X-base.widget

 If BASE macro is necessary, the best place is elm_widget.h.
 Thank you.
Dear Daniel,
The reason I used BASE was because I didn't/couldn't assume the name of 
that structure field. doing it-base is bad, because base is never 
clearly stated anywhere there. Doing it in a macro/casting would have 
been more appropriate, that's why I chose the one option that can easily 
be turned to both.
I didn't do anything drastic, because I don't know those changes well 
enough. I'd expect to have a function/macro to retrieve the disabled 
status from an Elm_Object_Item.
Please think about it and decide what you think is needed to be done.
--
Tom.
--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and packaging model 
of a cloud services business. Read Now!
http://www.accelacomm.com/jaw/sfnl/114/51491232/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel
--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and packaging model 
of a cloud services business. Read Now!
http://www.accelacomm.com/jaw/sfnl/114/51491232/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-12-08 Thread Tom Hacohen
On 08/12/11 11:28, ChunEon Park wrote:
 simply, we can call elm_widget_item_disabled_get API
 it's more clear.

It is, that's what I was talking about in my previous mail, didn't know 
it existed. :)

Mind fixing it?

Thanks,
Tom.


--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and packaging model 
of a cloud services business. Read Now!
http://www.accelacomm.com/jaw/sfnl/114/51491232/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-12-08 Thread ChunEon Park
You mean you will fix?

-Regards, Hermet-
 
-Original Message-
From: Tom Hacohenlt;tom.haco...@partner.samsung.comgt; 
To: Enlightenment developer 
listlt;enlightenment-devel@lists.sourceforge.netgt;
Cc: ChunEon Parklt;her...@naver.comgt;; 
enlightenment-...@lists.sourceforge.net
Sent: 11-12-08(목) 18:55:33
Subject: Re: [E-devel] E SVN: tasn trunk/elementary/src/lib
On 08/12/11 11:28, ChunEon Park wrote:
 simply, we can call elm_widget_item_disabled_get API
 it's more clear.
It is, that's what I was talking about in my previous mail, didn't know 
it existed. :)
Mind fixing it?
Thanks,
Tom.
--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and packaging model 
of a cloud services business. Read Now!
http://www.accelacomm.com/jaw/sfnl/114/51491232/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-12-08 Thread Tom Hacohen
I can fix it, will try to squeeze it in today, but if you get to it 
before I do, feel free to do it yourself. :P

--
Tom.

On 08/12/11 13:04, ChunEon Park wrote:
 You mean you will fix?


 
 -Regards, Hermet-

 -Original Message-
 *From:* Tom Hacohentom.haco...@partner.samsung.com
 *To:* Enlightenment developer
 listenlightenment-devel@lists.sourceforge.net
 *Cc:* ChunEon Parkher...@naver.com;
 enlightenment-...@lists.sourceforge.net
 *Sent:* 11-12-08(목) 18:55:33
 *Subject:* Re: [E-devel] E SVN: tasn trunk/elementary/src/lib
 On 08/12/11 11:28, ChunEon Park wrote:
   simply, we can call elm_widget_item_disabled_get API
   it's more clear.

 It is, that's what I was talking about in my previous mail, didn't know
 it existed. :)

 Mind fixing it?

 Thanks,
 Tom.






--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and packaging model 
of a cloud services business. Read Now!
http://www.accelacomm.com/jaw/sfnl/114/51491232/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-12-08 Thread ChunEon Park
Ok. then leave it to me. :)
just have feel free more. 

-Regards, Hermet-
 
-Original Message-
From: Tom Hacohenlt;tom.haco...@partner.samsung.comgt; 
To: ChunEon Parklt;her...@naver.comgt;
Cc: Enlightenment develolt;enlightenment-devel@lists.sourceforge.netgt;; 
enlightenment-...@lists.sourceforge.net
Sent: 11-12-08(목) 20:08:04
Subject: Re: [E-devel] E SVN: tasn trunk/elementary/src/lib
I can fix it, will try to squeeze it in today, but if you get to it 
before I do, feel free to do it yourself. :P
--
Tom.
On 08/12/11 13:04, ChunEon Park wrote:
 You mean you will fix?


 
 -Regards, Hermet-

 -Original Message-
 *From:* Tom Hacohenlt;tom.haco...@partner.samsung.comgt;
 *To:* Enlightenment developer
 listlt;enlightenment-devel@lists.sourceforge.netgt;
 *Cc:* ChunEon Parklt;her...@naver.comgt;;
 enlightenment-...@lists.sourceforge.net
 *Sent:* 11-12-08(목) 18:55:33
 *Subject:* Re: [E-devel] E SVN: tasn trunk/elementary/src/lib
 On 08/12/11 11:28, ChunEon Park wrote:
  simply, we can call elm_widget_item_disabled_get API
  it's more clear.

 It is, that's what I was talking about in my previous mail, didn't know
 it existed. :)

 Mind fixing it?

 Thanks,
 Tom.



--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and packaging model 
of a cloud services business. Read Now!
http://www.accelacomm.com/jaw/sfnl/114/51491232/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-12-08 Thread Tom Hacohen
Good, because I tried doing it now and noticed there is not 
item_disabled_set... :| Please fix it the way you see fit then.

--
Tom.

On 08/12/11 13:13, ChunEon Park wrote:
 Ok. then leave it to me. :)

 just have feel free more.


 
 -Regards, Hermet-

 -Original Message-
 *From:* Tom Hacohentom.haco...@partner.samsung.com
 *To:* ChunEon Parkher...@naver.com
 *Cc:* Enlightenment develoenlightenment-devel@lists.sourceforge.net;
 enlightenment-...@lists.sourceforge.net
 *Sent:* 11-12-08(목) 20:08:04
 *Subject:* Re: [E-devel] E SVN: tasn trunk/elementary/src/lib
 I can fix it, will try to squeeze it in today, but if you get to it
 before I do, feel free to do it yourself. :P

 --
 Tom.

 On 08/12/11 13:04, ChunEon Park wrote:
   You mean you will fix?
  
  
   
   -Regards, Hermet-
  
   -Original Message-
   *From:* Tom Hacohentom.haco...@partner.samsung.com
   *To:* Enlightenment developer
   listenlightenment-devel@lists.sourceforge.net
   *Cc:* ChunEon Parkher...@naver.com;
   enlightenment-...@lists.sourceforge.net
   *Sent:* 11-12-08(목) 18:55:33
   *Subject:* Re: [E-devel] E SVN: tasn trunk/elementary/src/lib
   On 08/12/11 11:28, ChunEon Park wrote:
simply, we can call elm_widget_item_disabled_get API
it's more clear.
  
   It is, that's what I was talking about in my previous mail, didn't know
   it existed. :)
  
   Mind fixing it?
  
   Thanks,
   Tom.
  
  
  






--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and packaging model 
of a cloud services business. Read Now!
http://www.accelacomm.com/jaw/sfnl/114/51491232/
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-12-07 Thread Daniel Juyung Seo
Hello Tom,
Thanks for you fix.

I have one question here.
I think this macro has no big benefit.

+#define BASE(it) ((it)-base)

There is no much difference between BASE(it) and it-base.
But there are two macros for base.view and base.widget in elm_widget.h

#define VIEW(X) X-base.view
#define WIDGET(X) X-base.widget

If BASE macro is necessary, the best place is elm_widget.h.
Thank you.

Daniel Juyung Seo (SeoZ)


On Wed, Dec 7, 2011 at 9:56 PM, Enlightenment SVN
no-re...@enlightenment.org wrote:
 Log:
 Elm toolbar: Fix brokeness introduced by commit 65708.

  Disabled is a property of Elm_Object_Item and was a property of
  Elm_Toolbar_Item as well. The aforementioned commit didn't remove the
  property from the latter and then used both properties in an
  inconsistent manner which caused data not to be up to date.

 Author:       tasn
 Date:         2011-12-07 04:56:34 -0800 (Wed, 07 Dec 2011)
 New Revision: 65989
 Trac:         http://trac.enlightenment.org/e/changeset/65989

 Modified:
  trunk/elementary/src/lib/elm_toolbar.c

 Modified: trunk/elementary/src/lib/elm_toolbar.c
 ===
 --- trunk/elementary/src/lib/elm_toolbar.c      2011-12-07 12:07:44 UTC (rev 
 65988)
 +++ trunk/elementary/src/lib/elm_toolbar.c      2011-12-07 12:56:34 UTC (rev 
 65989)
 @@ -4,6 +4,10 @@
  #include els_box.h
  #include els_icon.h

 +/* FIXME: I couldn't find a macro for it, this should be fixed.
 + * Just doing this commit to fix the brokeness that was introduced. */
 +#define BASE(it) ((it)-base)
 +
  typedef struct _Widget_Data Widget_Data;
  typedef struct _Elm_Toolbar_Item Elm_Toolbar_Item;

 @@ -40,7 +44,6 @@
       Eina_Bool visible : 1;
    } prio;
    Eina_Bool selected : 1;
 -   Eina_Bool disabled : 1;
    Eina_Bool separator : 1;
    Eina_Bool menu : 1;
    Eina_List *states;
 @@ -150,7 +153,7 @@
    Eina_Bool sel;

    if (!wd) return;
 -   if ((it-disabled) || (it-separator)) return;
 +   if ((BASE(it)-disabled) || (it-separator)) return;
    sel = it-selected;

    if (!wd-no_select)
 @@ -223,9 +226,9 @@
    Widget_Data *wd = elm_widget_data_get(WIDGET(it));

    if (!wd) return;
 -   if (it-disabled == disabled) return;
 -   it-disabled = !!disabled;
 -   if (it-disabled)
 +   if (BASE(it)-disabled == disabled) return;
 +   BASE(it)-disabled = !!disabled;
 +   if (BASE(it)-disabled)
      {
         edje_object_signal_emit(VIEW(it), elm,state,disabled, elm);
         elm_widget_signal_emit(it-icon, elm,state,disabled, elm);
 @@ -317,7 +320,7 @@
              edje_object_signal_emit(view, elm,state,selected, elm);
              elm_widget_signal_emit(it-icon, elm,state,selected, elm);
           }
 -        if (it-disabled)
 +        if (BASE(it)-disabled)
           {
              edje_object_signal_emit(view, elm,state,disabled, elm);
              elm_widget_signal_emit(it-icon, elm,state,disabled, elm);
 @@ -540,7 +543,7 @@
                             menu_it = elm_menu_item_add(menu, NULL,
                                                 it-icon_str, it-label,
                                                 _elm_toolbar_item_menu_cb, 
 it);
 -                            elm_object_item_disabled_set(menu_it, 
 it-disabled);
 +                            elm_object_item_disabled_set(menu_it, 
 BASE(it)-disabled);
                             if (it-o_menu)
                               elm_menu_clone(it-o_menu, menu, menu_it);
                          }
 @@ -732,7 +735,7 @@
    Elm_Toolbar_Item *it = (Elm_Toolbar_Item *)item;
    if (it-separator)
       return strdup(E_(Separator));
 -   else if (it-disabled)
 +   else if (BASE(it)-disabled)
       return strdup(E_(State: Disabled));
    else if (it-selected)
       return strdup(E_(State: Selected));
 @@ -1763,7 +1766,7 @@
                                        wd-icon_size,
                                        elm,state,icon_set,backward);
      }
 -   if (item-disabled)
 +   if (BASE(item)-disabled)
      elm_widget_signal_emit(item-icon, elm,state,disabled, elm);
    else
      elm_widget_signal_emit(item-icon, elm,state,enabled, elm);


 --
 Cloud Services Checklist: Pricing and Packaging Optimization
 This white paper is intended to serve as a reference, checklist and point of
 discussion for anyone considering optimizing the pricing and packaging model
 of a cloud services business. Read Now!
 http://www.accelacomm.com/jaw/sfnl/114/51491232/
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn

--
Cloud Services Checklist: Pricing and Packaging Optimization
This white paper is intended to serve as a reference, checklist and point of 
discussion for anyone considering optimizing the pricing and 

Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-08-29 Thread Gustavo Barbieri
Hey Tasn, need to check but before there were no limits that the
tooltip must be on an elm object. It could be an edje or a single
rectangle. All it should use are mouse events.

--Gustavo

Sent from my iPhone

On 28/08/2011, at 11:13, Enlightenment SVN no-re...@enlightenment.org wrote:

 Log:
 Elm tooltip: Added checks if the object passed is an elm object.

 Author:   tasn
 Date: 2011-08-28 07:12:38 -0700 (Sun, 28 Aug 2011)
 New Revision: 62919
 Trac: http://trac.enlightenment.org/e/changeset/62919

 Modified:
  trunk/elementary/src/lib/elm_widget.c trunk/elementary/src/lib/elm_widget.h 
 trunk/elementary/src/lib/els_tooltip.c

 Modified: trunk/elementary/src/lib/elm_widget.c
 ===
 --- trunk/elementary/src/lib/elm_widget.c2011-08-28 13:28:12 UTC (rev 
 62918)
 +++ trunk/elementary/src/lib/elm_widget.c2011-08-28 14:12:38 UTC (rev 
 62919)
 @@ -2398,6 +2398,23 @@
 }

 EAPI Eina_Bool
 +elm_widget_is_check(const Evas_Object *obj)
 +{
 +   static int abort_on_warn = -1;
 +   if (elm_widget_is(obj))
 +  return EINA_TRUE;
 +
 +   ERR(Passing Object: %p., obj);
 +   if (abort_on_warn == -1)
 + {
 +if (getenv(ELM_ERROR_ABORT)) abort_on_warn = 1;
 +else abort_on_warn = 0;
 + }
 +   if (abort_on_warn == 1) abort();
 +   return EINA_FALSE;
 +}
 +
 +EAPI Eina_Bool
 elm_widget_type_check(const Evas_Object *obj,
   const char*type)
 {

 Modified: trunk/elementary/src/lib/elm_widget.h
 ===
 --- trunk/elementary/src/lib/elm_widget.h2011-08-28 13:28:12 UTC (rev 
 62918)
 +++ trunk/elementary/src/lib/elm_widget.h2011-08-28 14:12:38 UTC (rev 
 62919)
 @@ -400,6 +400,7 @@
 EAPI Eina_Boolelm_widget_theme_object_set(Evas_Object *obj, 
 Evas_Object *edj, const char *wname, const char *welement, const char 
 *wstyle);
 EAPI void elm_widget_type_register(const char **ptr);
 EAPI void elm_widget_type_unregister(const char **ptr);
 +EAPI Eina_Boolelm_widget_is_check(const Evas_Object *obj);
 EAPI Eina_Boolelm_widget_type_check(const Evas_Object *obj, const 
 char *type);
 EAPI Eina_List   *elm_widget_stringlist_get(const char *str);
 EAPI void elm_widget_stringlist_free(Eina_List *list);
 @@ -671,6 +672,9 @@
   } \
} while (0)

 +#define ELM_CHECK_WID_IS(obj) \
 +   if (!elm_widget_is_check(obj)) return
 +
 #define ELM_CHECK_WIDTYPE(obj, widtype) \
if (!elm_widget_type_check((obj), (widtype))) return


 Modified: trunk/elementary/src/lib/els_tooltip.c
 ===
 --- trunk/elementary/src/lib/els_tooltip.c2011-08-28 13:28:12 UTC (rev 
 62918)
 +++ trunk/elementary/src/lib/els_tooltip.c2011-08-28 14:12:38 UTC (rev 
 62919)
 @@ -717,6 +717,7 @@
 EAPI void
 elm_object_tooltip_show(Evas_Object *obj)
 {
 +   ELM_CHECK_WID_IS(obj);
ELM_TOOLTIP_GET_OR_RETURN(tt, obj);
tt-visible_lock = EINA_TRUE;
_elm_tooltip_show(tt);
 @@ -734,6 +735,7 @@
 EAPI void
 elm_object_tooltip_hide(Evas_Object *obj)
 {
 +   ELM_CHECK_WID_IS(obj);
ELM_TOOLTIP_GET_OR_RETURN(tt, obj);
tt-visible_lock = EINA_FALSE;
_elm_tooltip_hide_anim_start(tt);
 @@ -754,6 +756,7 @@
 EAPI void
 elm_object_tooltip_text_set(Evas_Object *obj, const char *text)
 {
 +   ELM_CHECK_WID_IS(obj);
EINA_SAFETY_ON_NULL_RETURN(obj);
EINA_SAFETY_ON_NULL_RETURN(text);

 @@ -785,6 +788,7 @@
 EAPI void
 elm_object_tooltip_content_cb_set(Evas_Object *obj, Elm_Tooltip_Content_Cb 
 func, const void *data, Evas_Smart_Cb del_cb)
 {
 +   ELM_CHECK_WID_IS(obj);
elm_object_sub_tooltip_content_cb_set(obj, obj, func, data, del_cb);
 }

 @@ -804,6 +808,7 @@
 EAPI void
 elm_object_tooltip_unset(Evas_Object *obj)
 {
 +   ELM_CHECK_WID_IS(obj);
ELM_TOOLTIP_GET_OR_RETURN(tt, obj);
_elm_tooltip_unset(tt);
 }
 @@ -821,6 +826,7 @@
 EAPI void
 elm_object_tooltip_style_set(Evas_Object *obj, const char *style)
 {
 +   ELM_CHECK_WID_IS(obj);
ELM_TOOLTIP_GET_OR_RETURN(tt, obj);
if (!eina_stringshare_replace(tt-style, style)) return;
elm_tooltip_theme(tt);
 @@ -836,6 +842,7 @@
 EAPI const char *
 elm_object_tooltip_style_get(const Evas_Object *obj)
 {
 +   ELM_CHECK_WID_IS(obj);
ELM_TOOLTIP_GET_OR_RETURN(tt, obj, NULL);
return tt-style ? tt-style : default;
 }
 @@ -883,6 +890,7 @@
 EAPI Eina_Bool
 elm_tooltip_size_restrict_disable(Evas_Object *obj, Eina_Bool disable)
 {
 +   ELM_CHECK_WID_IS(obj);
ELM_TOOLTIP_GET_OR_RETURN(tt, obj, EINA_FALSE);
return tt-free_size = disable;
 }
 @@ -899,6 +907,7 @@
 EAPI Eina_Bool
 elm_tooltip_size_restrict_disabled_get(const Evas_Object *obj)
 {
 +   ELM_CHECK_WID_IS(obj);
ELM_TOOLTIP_GET_OR_RETURN(tt, obj, EINA_FALSE);
return tt-free_size;
 }


 --
 EMC VNX: the world's 

Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-08-29 Thread Tom Hacohen
On 29/08/11 14:32, Gustavo Barbieri wrote:
 Hey Tasn, need to check but before there were no limits that the
 tooltip must be on an elm object. It could be an edje or a single
 rectangle. All it should use are mouse events.

 --Gustavo

 Sent from my iPhone

Ah. I'm sorry then, will revert, my bad. Added it because a colleague of 
mine tried to shove an Eina_List in there and he couldn't understand 
what went wrong, but I guess my checks are bad.

Thanks for the notice,
Tom.

--
EMC VNX: the world's simplest storage, starting under $10K
The only unified storage solution that offers unified management 
Up to 160% more powerful than alternatives and 25% more efficient. 
Guaranteed. http://p.sf.net/sfu/emc-vnx-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-08-29 Thread Gustavo Barbieri
Went bad? But evas_object_data_get() should be safe with it using magic numbers.

--Gustavo

Sent from my iPhone

On 29/08/2011, at 08:36, Tom Hacohen tom.haco...@partner.samsung.com wrote:

 On 29/08/11 14:32, Gustavo Barbieri wrote:
 Hey Tasn, need to check but before there were no limits that the
 tooltip must be on an elm object. It could be an edje or a single
 rectangle. All it should use are mouse events.

 --Gustavo

 Sent from my iPhone

 Ah. I'm sorry then, will revert, my bad. Added it because a colleague of mine 
 tried to shove an Eina_List in there and he couldn't understand what went 
 wrong, but I guess my checks are bad.

 Thanks for the notice,
 Tom.

--
EMC VNX: the world's simplest storage, starting under $10K
The only unified storage solution that offers unified management 
Up to 160% more powerful than alternatives and 25% more efficient. 
Guaranteed. http://p.sf.net/sfu/emc-vnx-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-08-29 Thread Tom Hacohen
Ok, reverted. A big win for informative commit logs that made it easier 
for you to detect this bad commit. :)

On 29/08/11 14:43, Gustavo Barbieri wrote:
 Went bad? But evas_object_data_get() should be safe with it using magic 
 numbers.

I'm not sure I got you, you suggest I'll change it to check for Evas 
Objects? I guess that's the right thing to do in this case. I ain't 
gonna do it now, as I'm busy with something else, hopefully when I get 
some free time.

--
Tom.

--
EMC VNX: the world's simplest storage, starting under $10K
The only unified storage solution that offers unified management 
Up to 160% more powerful than alternatives and 25% more efficient. 
Guaranteed. http://p.sf.net/sfu/emc-vnx-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-08-29 Thread Sachiel
2011/8/29 Tom Hacohen tom.haco...@partner.samsung.com:
 Ok, reverted. A big win for informative commit logs that made it easier
 for you to detect this bad commit. :)

 On 29/08/11 14:43, Gustavo Barbieri wrote:
 Went bad? But evas_object_data_get() should be safe with it using magic 
 numbers.

 I'm not sure I got you, you suggest I'll change it to check for Evas
 Objects? I guess that's the right thing to do in this case. I ain't
 gonna do it now, as I'm busy with something else, hopefully when I get
 some free time.


Or tell your friend to read the warnings in the compile log.
Or not to cast pointers to incompatible types to silence those warnings.

 --
 Tom.

 --
 EMC VNX: the world's simplest storage, starting under $10K
 The only unified storage solution that offers unified management
 Up to 160% more powerful than alternatives and 25% more efficient.
 Guaranteed. http://p.sf.net/sfu/emc-vnx-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


--
EMC VNX: the world's simplest storage, starting under $10K
The only unified storage solution that offers unified management 
Up to 160% more powerful than alternatives and 25% more efficient. 
Guaranteed. http://p.sf.net/sfu/emc-vnx-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-08-29 Thread Tom Hacohen
On 29/08/11 14:59, Iván Briano (Sachiel) wrote:
 Or tell your friend to read the warnings in the compile log.
 Or not to cast pointers to incompatible types to silence those warnings.

I tell him that all the time...
To his defence though, in this case it wasn't entirely his fault. He did 
something bad that almost everyone in efl. He used void * pointers 
without casting to the wanted type before (by using a local variable for 
example).
He used the value of eina_list_data_get as a parameter to that function 
without noticing it wasn't an Evas_Object (I was wrong earlier when I 
said he passed an Eina_List, he actually passed an Elm_List_Item).

No way for the compiler to detect that.

--
Tom.


--
EMC VNX: the world's simplest storage, starting under $10K
The only unified storage solution that offers unified management 
Up to 160% more powerful than alternatives and 25% more efficient. 
Guaranteed. http://p.sf.net/sfu/emc-vnx-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-08-29 Thread Gustavo Sverzut Barbieri
On Mon, Aug 29, 2011 at 9:07 AM, Tom Hacohen
tom.haco...@partner.samsung.com wrote:
 On 29/08/11 14:59, Iván Briano (Sachiel) wrote:
 Or tell your friend to read the warnings in the compile log.
 Or not to cast pointers to incompatible types to silence those warnings.

 I tell him that all the time...
 To his defence though, in this case it wasn't entirely his fault. He did
 something bad that almost everyone in efl. He used void * pointers
 without casting to the wanted type before (by using a local variable for
 example).
 He used the value of eina_list_data_get as a parameter to that function
 without noticing it wasn't an Evas_Object (I was wrong earlier when I
 said he passed an Eina_List, he actually passed an Elm_List_Item).

 No way for the compiler to detect that.

But I'm still amazed why Evas' own magic pointer checking did not caught it.

-- 
Gustavo Sverzut Barbieri
http://profusion.mobi embedded systems
--
MSN: barbi...@gmail.com
Skype: gsbarbieri
Mobile: +55 (19) 9225-2202

--
EMC VNX: the world's simplest storage, starting under $10K
The only unified storage solution that offers unified management 
Up to 160% more powerful than alternatives and 25% more efficient. 
Guaranteed. http://p.sf.net/sfu/emc-vnx-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-05-19 Thread Leif Middelschulte
2011/5/19 Enlightenment SVN no-re...@enlightenment.org:
 Log:
 Elm entry: strndup is not portable, use memcpy.
If it's in the context of copying a string, why don't you define
strndup as a macro for platforms it's not supported on?

BR,

Leif

  Thanks to vtorri for the notice.

 Author:       tasn
 Date:         2011-05-19 06:27:46 -0700 (Thu, 19 May 2011)
 New Revision: 59540
 Trac:         http://trac.enlightenment.org/e/changeset/59540

 Modified:
  trunk/elementary/src/lib/elm_entry.c

 Modified: trunk/elementary/src/lib/elm_entry.c
 ===
 --- trunk/elementary/src/lib/elm_entry.c        2011-05-19 13:24:06 UTC (rev 
 59539)
 +++ trunk/elementary/src/lib/elm_entry.c        2011-05-19 13:27:46 UTC (rev 
 59540)
 @@ -1884,19 +1884,25 @@

    len = strlen(entry);
    /* Split to ~_CHUNK_SIZE chunks */
 -   if (len = _CHUNK_SIZE)
 +   if (len  _CHUNK_SIZE)
      {
 -        edje_object_part_text_set(wd-ent, elm.text, entry);
 +        wd-append_text_left = (char *) malloc(len + 1);
      }
 -   else
 +
 +   /* If we decided to use the idler */
 +   if (wd-append_text_left)
      {
         /* Need to clear the entry first */
         edje_object_part_text_set(wd-ent, elm.text, );
 -        wd-append_text_left = strndup(entry, len);
 +        memcpy(wd-append_text_left, entry, len + 1);
         wd-append_text_position = 0;
         wd-append_text_len = len;
         wd-append_text_idler = ecore_idler_add(_text_append_idler, obj);
      }
 +   else
 +     {
 +        edje_object_part_text_set(wd-ent, elm.text, entry);
 +     }
  }

  /**


 --
 What Every C/C++ and Fortran developer Should Know!
 Read this article and learn how Intel has extended the reach of its
 next-generation tools to help Windows* and Linux* C/C++ and Fortran
 developers boost performance applications - including clusters.
 http://p.sf.net/sfu/intel-dev2devmay
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn


--
What Every C/C++ and Fortran developer Should Know!
Read this article and learn how Intel has extended the reach of its 
next-generation tools to help Windows* and Linux* C/C++ and Fortran 
developers boost performance applications - including clusters. 
http://p.sf.net/sfu/intel-dev2devmay
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-05-19 Thread Tom Hacohen
On Thu, 2011-05-19 at 18:19 +0200, Leif Middelschulte wrote:
 2011/5/19 Enlightenment SVN no-re...@enlightenment.org:
  Log:
  Elm entry: strndup is not portable, use memcpy.
 If it's in the context of copying a string, why don't you define
 strndup as a macro for platforms it's not supported on?

That's why I used it in the first place, I assumed we already had in in
Evil, but vtorri pointed out we don't. memcpy is better in this case
anyway, so I don't really mind.

--
Tom.


--
What Every C/C++ and Fortran developer Should Know!
Read this article and learn how Intel has extended the reach of its 
next-generation tools to help Windows* and Linux* C/C++ and Fortran 
developers boost performance applications - including clusters. 
http://p.sf.net/sfu/intel-dev2devmay
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-04-06 Thread Daniel Juyung Seo
Tom!
This is so good. I waited this patch for so long.
Sorry I was too busy to fix this. ; or lazy :)

Thanks!
Daniel Juyung Seo (SeoZ)

On Wed, Apr 6, 2011 at 4:51 PM, Enlightenment SVN 
no-re...@enlightenment.org wrote:

 Log:
 Elementary smart-scroller: Fixed scroller jumping in some cases.

  In some cases, for example resizing the GenGrid test or just using
  ephoto, the scroller would jump to the right before going to it's
  proper direction. We should check if the position is below minimum
  after we reduce the position, and not instead.

 Author:   tasn
 Date: 2011-04-06 00:51:26 -0700 (Wed, 06 Apr 2011)
 New Revision: 58383
 Trac: http://trac.enlightenment.org/e/changeset/58383

 Modified:
  trunk/elementary/src/lib/els_scroller.c

 Modified: trunk/elementary/src/lib/els_scroller.c
 ===
 --- trunk/elementary/src/lib/els_scroller.c 2011-04-06 07:37:13 UTC
 (rev 58382)
 +++ trunk/elementary/src/lib/els_scroller.c 2011-04-06 07:51:26 UTC
 (rev 58383)
 @@ -585,8 +585,8 @@
 x = x / (sd-pagesize_h);
 x = x * (sd-pagesize_h);
  }
 +   if ((x + w)  cw) x = cw - w;
if (x  minx) x = minx;
 -   else if ((x + w)  cw) x = cw - w;
return x;
  }

 @@ -614,8 +614,8 @@
 y = y / (sd-pagesize_v);
 y = y * (sd-pagesize_v);
  }
 +   if ((y + h)  ch) y = ch - h;
if (y  miny) y = miny;
 -   else if ((y + h)  ch) y = ch - h;
return y;
  }

 @@ -1061,11 +1061,11 @@
 sd-down.pdy = 0;
  }
x = nx;
 +   if ((x + w)  cw) x = cw - w;
if (x  minx) x = minx;
 -   else if ((x + w)  cw) x = cw - w;
y = ny;
 +   if ((y + h)  ch) y = ch - h;
if (y  miny) y = miny;
 -   else if ((y + h)  ch) y = ch - h;
elm_smart_scroller_child_pos_set(obj, x, y);
  }

 @@ -1341,12 +1341,12 @@
 sd-down.pdy = 0;
  }
x = nx;
 +   if ((x + w)  cw) x = cw - w;
if (x  minx) x = minx;
 -   else if ((x + w)  cw) x = cw - w;
_smart_scrollto_x(sd, _elm_config-bring_in_scroll_friction, x);
y = ny;
 +   if ((y + h)  ch) y = ch - h;
if (y  miny) y = miny;
 -   else if ((y + h)  ch) y = ch - h;
_smart_scrollto_y(sd, _elm_config-bring_in_scroll_friction, y);
  }




 --
 Xperia(TM) PLAY
 It's a major breakthrough. An authentic gaming
 smartphone on the nation's most reliable network.
 And it wants your games.
 http://p.sf.net/sfu/verizon-sfdev
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn

--
Xperia(TM) PLAY
It's a major breakthrough. An authentic gaming
smartphone on the nation's most reliable network.
And it wants your games.
http://p.sf.net/sfu/verizon-sfdev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: tasn trunk/elementary/src/lib

2011-04-06 Thread Tom Hacohen
Lazy bastard! I forgot about it, but got reminded by ephoto yesterday
night, so I decided to fix it. :)

--
Tom.

On Wed, 2011-04-06 at 18:28 +0900, Daniel Juyung Seo wrote:
 Tom!
 This is so good. I waited this patch for so long.
 Sorry I was too busy to fix this. ; or lazy :)
 
 Thanks!
 Daniel Juyung Seo (SeoZ)
 
 On Wed, Apr 6, 2011 at 4:51 PM, Enlightenment SVN 
 no-re...@enlightenment.org wrote:
 
  Log:
  Elementary smart-scroller: Fixed scroller jumping in some cases.
 
   In some cases, for example resizing the GenGrid test or just using
   ephoto, the scroller would jump to the right before going to it's
   proper direction. We should check if the position is below minimum
   after we reduce the position, and not instead.
 
  Author:   tasn
  Date: 2011-04-06 00:51:26 -0700 (Wed, 06 Apr 2011)
  New Revision: 58383
  Trac: http://trac.enlightenment.org/e/changeset/58383
 
  Modified:
   trunk/elementary/src/lib/els_scroller.c
 
  Modified: trunk/elementary/src/lib/els_scroller.c
  ===
  --- trunk/elementary/src/lib/els_scroller.c 2011-04-06 07:37:13 UTC
  (rev 58382)
  +++ trunk/elementary/src/lib/els_scroller.c 2011-04-06 07:51:26 UTC
  (rev 58383)
  @@ -585,8 +585,8 @@
  x = x / (sd-pagesize_h);
  x = x * (sd-pagesize_h);
   }
  +   if ((x + w)  cw) x = cw - w;
 if (x  minx) x = minx;
  -   else if ((x + w)  cw) x = cw - w;
 return x;
   }
 
  @@ -614,8 +614,8 @@
  y = y / (sd-pagesize_v);
  y = y * (sd-pagesize_v);
   }
  +   if ((y + h)  ch) y = ch - h;
 if (y  miny) y = miny;
  -   else if ((y + h)  ch) y = ch - h;
 return y;
   }
 
  @@ -1061,11 +1061,11 @@
  sd-down.pdy = 0;
   }
 x = nx;
  +   if ((x + w)  cw) x = cw - w;
 if (x  minx) x = minx;
  -   else if ((x + w)  cw) x = cw - w;
 y = ny;
  +   if ((y + h)  ch) y = ch - h;
 if (y  miny) y = miny;
  -   else if ((y + h)  ch) y = ch - h;
 elm_smart_scroller_child_pos_set(obj, x, y);
   }
 
  @@ -1341,12 +1341,12 @@
  sd-down.pdy = 0;
   }
 x = nx;
  +   if ((x + w)  cw) x = cw - w;
 if (x  minx) x = minx;
  -   else if ((x + w)  cw) x = cw - w;
 _smart_scrollto_x(sd, _elm_config-bring_in_scroll_friction, x);
 y = ny;
  +   if ((y + h)  ch) y = ch - h;
 if (y  miny) y = miny;
  -   else if ((y + h)  ch) y = ch - h;
 _smart_scrollto_y(sd, _elm_config-bring_in_scroll_friction, y);
   }
 
 
 
 
  --
  Xperia(TM) PLAY
  It's a major breakthrough. An authentic gaming
  smartphone on the nation's most reliable network.
  And it wants your games.
  http://p.sf.net/sfu/verizon-sfdev
  ___
  enlightenment-svn mailing list
  enlightenment-...@lists.sourceforge.net
  https://lists.sourceforge.net/lists/listinfo/enlightenment-svn
 
 --
 Xperia(TM) PLAY
 It's a major breakthrough. An authentic gaming
 smartphone on the nation's most reliable network.
 And it wants your games.
 http://p.sf.net/sfu/verizon-sfdev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel



--
Xperia(TM) PLAY
It's a major breakthrough. An authentic gaming
smartphone on the nation's most reliable network.
And it wants your games.
http://p.sf.net/sfu/verizon-sfdev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel